==> hydrobricks-0.5.0.tar.gz: hydrobricks-0.5.0/README.md <==
# hydrobricks

> :warning: **hydrobricks is still in its very early stages and options are limited at this point...**

A modular hydrological modelling framework.

[![DOI](https://zenodo.org/badge/301952016.svg)](https://zenodo.org/badge/latestdoi/301952016)
[![GitHub release](https://img.shields.io/github/v/release/hydrobricks/hydrobricks)](https://github.com/hydrobricks/hydrobricks/releases)
[![PyPI](https://img.shields.io/pypi/v/hydrobricks)](https://pypi.org/project/hydrobricks/)
![Static Badge](https://img.shields.io/badge/python-%3E%3D3.8-blue)
[![Core Tests Linux](https://github.com/hydrobricks/hydrobricks/actions/workflows/core-tests-linux.yml/badge.svg)](https://github.com/hydrobricks/hydrobricks/actions/workflows/core-tests-linux.yml)
[![Python Wheels](https://github.com/hydrobricks/hydrobricks/actions/workflows/python-wheels.yml/badge.svg)](https://github.com/hydrobricks/hydrobricks/actions/workflows/python-wheels.yml)
[![Core Doxygen](https://github.com/hydrobricks/hydrobricks/actions/workflows/core-doxygen.yml/badge.svg)](https://github.com/hydrobricks/hydrobricks/actions/workflows/core-doxygen.yml)
[![Documentation Status](https://readthedocs.org/projects/hydrobricks/badge/?version=latest)](https://hydrobricks.readthedocs.io/en/latest/?badge=latest)
[![pre-commit.ci status](https://results.pre-commit.ci/badge/github/hydrobricks/hydrobricks/main.svg)](https://results.pre-commit.ci/latest/github/hydrobricks/hydrobricks/main)
[![Codecov](https://img.shields.io/codecov/c/github/hydrobricks/hydrobricks)](https://codecov.io/gh/hydrobricks/hydrobricks)
[![Codacy Badge](https://app.codacy.com/project/badge/Grade/639e5bb76690488f9aac5feb89722bfa)](https://www.codacy.com/gh/hydrobricks/hydrobricks/dashboard?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=hydrobricks/hydrobricks&amp;utm_campaign=Badge_Grade)


## Install

Wheels are available to install from PyPI (https://pypi.org/project/hydrobricks/)

Install: ```pip install hydrobricks```

## Resources
*   **Documentation**: https://hydrobricks.readthedocs.io/en/latest/
*   How to build: https://github.com/hydrobricks/hydrobricks/wiki
*   Code documentation of the core: https://hydrobricks.github.io/hydrobricks-doc-core/

==> hydrobricks-0.6.2.tar.gz: hydrobricks-0.6.2/README.md <==
# hydrobricks

> :warning: **hydrobricks is still in its very early stages and options are limited at this point...**

A modular hydrological modelling framework.

[![DOI](https://zenodo.org/badge/301952016.svg)](https://zenodo.org/badge/latestdoi/301952016)
[![GitHub release](https://img.shields.io/github/v/release/hydrobricks/hydrobricks)](https://github.com/hydrobricks/hydrobricks/releases)
[![PyPI](https://img.shields.io/pypi/v/hydrobricks)](https://pypi.org/project/hydrobricks/)
![Static Badge](https://img.shields.io/badge/python-%3E%3D3.8-blue)
[![Core Tests](https://github.com/hydrobricks/hydrobricks/actions/workflows/core-tests-linux.yml/badge.svg)](https://github.com/hydrobricks/hydrobricks/actions/workflows/core-tests-linux.yml)
[![Python Tests](https://github.com/hydrobricks/hydrobricks/actions/workflows/python-tests-linux.yml/badge.svg)](https://github.com/hydrobricks/hydrobricks/actions/workflows/python-tests-linux.yml)
[![Python Wheels](https://github.com/hydrobricks/hydrobricks/actions/workflows/python-wheels.yml/badge.svg)](https://github.com/hydrobricks/hydrobricks/actions/workflows/python-wheels.yml)
[![Core Doxygen](https://github.com/hydrobricks/hydrobricks/actions/workflows/core-doxygen.yml/badge.svg)](https://github.com/hydrobricks/hydrobricks/actions/workflows/core-doxygen.yml)
[![Documentation Status](https://readthedocs.org/projects/hydrobricks/badge/?version=latest)](https://hydrobricks.readthedocs.io/en/latest/?badge=latest)
[![pre-commit.ci status](https://results.pre-commit.ci/badge/github/hydrobricks/hydrobricks/main.svg)](https://results.pre-commit.ci/latest/github/hydrobricks/hydrobricks/main)
[![Codecov](https://img.shields.io/codecov/c/github/hydrobricks/hydrobricks)](https://codecov.io/gh/hydrobricks/hydrobricks)
[![Codacy Badge](https://app.codacy.com/project/badge/Grade/639e5bb76690488f9aac5feb89722bfa)](https://www.codacy.com/gh/hydrobricks/hydrobricks/dashboard?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=hydrobricks/hydrobricks&amp;utm_campaign=Badge_Grade)


## Install

Wheels are available to install from PyPI (https://pypi.org/project/hydrobricks/)

Install: ```pip install hydrobricks```

## Resources
*   **Documentation**: https://hydrobricks.readthedocs.io/en/latest/
*   How to build: https://github.com/hydrobricks/hydrobricks/wiki
*   Code documentation of the core: https://hydrobricks.github.io/hydrobricks-doc-core/
